@@ -445,13 +445,13 @@ recurrence.DateFormat.prototype = {
     S: function() {
         var day = this.data.getDate();
         var ordinal_indicator = recurrence.display.ordinal_indicator;
-        var language_code = recurrence.language_code;
+        var language_code = recurrence.language_code || "en-us";
         if (language_code in ordinal_indicator) {
             return ordinal_indicator[language_code](day);
-	} else if (language_code.split('-')[0] in ordinal_indicator) {
-	    return ordinal_indicator[language_code.split('-')[0]](day)
-	}
-        return '';
+        } else if (language_code.split("-")[0] in ordinal_indicator) {
+            return ordinal_indicator[language_code.split("-")[0]](day);
+        }
+        return "";
     },
 
     t: function() {
